@@ -210,8 +210,6 @@ FindAllMarkers <- function(
 #' associated output column (e.g. CTRL_p_val). If only one group is tested in the grouping.var, max
 #' and combined p-values are not returned.
 #'
-#' @importFrom metap minimump
-#'
 #' @export
 #'
 #' @examples
@@ -229,10 +227,23 @@ FindConservedMarkers <- function(
   grouping.var,
   assay = 'RNA',
   slot = 'data',
-  meta.method = minimump,
+  meta.method = metap::minimump,
   verbose = TRUE,
   ...
 ) {
+  metap.installed <- PackageCheck("metap", error = FALSE)
+  if (!metap.installed[1]) {
+    stop(
+      "Please install the metap package to use FindConservedMarkers.",
+      "\nThis can be accomplished with the following commands: ",
+      "\n----------------------------------------",
+      "\ninstall.packages('BiocManager')",
+      "\nBiocManager::install('multtest')",
+      "\ninstall.packages('metap')",
+      "\n----------------------------------------",
+      call. = FALSE
+    )
+  }
   if (!is.function(x = meta.method)) {
     stop("meta.method should be a function from the metap package. Please see https://cran.r-project.org/web/packages/metap/metap.pdf for a detailed description of the available functions.")
   }
@@ -354,12 +365,13 @@ FindConservedMarkers <- function(
         return(meta.method(x)$p)
       }
     ))
-    colnames(x = combined.pval) <- paste0(
-      as.character(x = formals()$meta.method),
-      "_p_val"
-    )
+    meta.method.name <- as.character(x = formals()$meta.method)
+    if (length(x = meta.method.name) == 3) {
+      meta.method.name <- meta.method.name[3]
+    }
+    colnames(x = combined.pval) <- paste0(meta.method.name, "_p_val")
     markers.combined <- cbind(markers.combined, combined.pval)
-    markers.combined <- markers.combined[order(markers.combined[, paste0(as.character(x = formals()$meta.method), "_p_val")]), ]
+    markers.combined <- markers.combined[order(markers.combined[, paste0(meta.method.name, "_p_val")]), ]
   } else {
     warning("Only a single group was tested", call. = FALSE, immediate. = TRUE)
   }
@@ -659,7 +671,7 @@ FindMarkers.default <- function(
   )
   if (is.null(x = reduction)) {
     diff.col <- ifelse(
-      test = slot == "scale.data" || test.use == 'roc',
+      test = slot == "scale.data",
       yes = "avg_diff",
       no = "avg_logFC"
     )
@@ -1505,7 +1517,9 @@ RegularizedTheta <- function(cm, latent.data, min.theta = 0.01, bin.size = 128)
 # Differential expression using Wilcoxon Rank Sum
 #
 # Identifies differentially expressed genes between two groups of cells using
-# a Wilcoxon Rank Sum test
+# a Wilcoxon Rank Sum test. Makes use of limma::rankSumTestWithCorrelation for a
+# more efficient implementation of the wilcoxon test. Thanks to Yunshun Chen and
+# Gordon Smyth for suggesting the limma implementation.
 #
 # @param data.use Data matrix to test
 # @param cells.1 Group 1 cells
@@ -1535,21 +1549,52 @@ WilcoxDETest <- function(
   verbose = TRUE,
   ...
 ) {
-  group.info <- data.frame(row.names = c(cells.1, cells.2))
-  group.info[cells.1, "group"] <- "Group1"
-  group.info[cells.2, "group"] <- "Group2"
-  group.info[, "group"] <- factor(x = group.info[, "group"])
-  data.use <- data.use[, rownames(x = group.info), drop = FALSE]
+  data.use <- data.use[, c(cells.1, cells.2), drop = FALSE]
+  j <- seq_len(length.out = length(x = cells.1))
   my.sapply <- ifelse(
     test = verbose && nbrOfWorkers() == 1,
     yes = pbsapply,
     no = future_sapply
   )
-  p_val <- my.sapply(
-    X = 1:nrow(x = data.use),
-    FUN = function(x) {
-      return(wilcox.test(data.use[x, ] ~ group.info[, "group"], ...)$p.value)
-    }
+  overflow.check <- ifelse(
+    test = is.na(x = suppressWarnings(length(x = data.use[1, ]) * length(x = data.use[1, ]))),
+    yes = FALSE,
+    no = TRUE
   )
+  limma.check <- PackageCheck("limma", error = FALSE)
+  if (limma.check[1] && overflow.check) {
+    p_val <- my.sapply(
+      X = 1:nrow(x = data.use),
+      FUN = function(x) {
+        return(min(2 * min(limma::rankSumTestWithCorrelation(index = j, statistics = data.use[x, ])), 1))
+      }
+    )
+  } else {
+    if (getOption('Seurat.limma.wilcox.msg', TRUE) && overflow.check) {
+      message(
+        "For a more efficient implementation of the Wilcoxon Rank Sum Test,",
+        "\n(default method for FindMarkers) please install the limma package",
+        "\n--------------------------------------------",
+        "\ninstall.packages('BiocManager')",
+        "\nBiocManager::install('limma')",
+        "\n--------------------------------------------",
+        "\nAfter installation of limma, Seurat will automatically use the more ",
+        "\nefficient implementation (no further action necessary).",
+        "\nThis message will be shown once per session"
+      )
+      options(Seurat.limma.wilcox.msg = FALSE)
+    }
+    group.info <- data.frame(row.names = c(cells.1, cells.2))
+    group.info[cells.1, "group"] <- "Group1"
+    group.info[cells.2, "group"] <- "Group2"
+    group.info[, "group"] <- factor(x = group.info[, "group"])
+    data.use <- data.use[, rownames(x = group.info), drop = FALSE]
+    p_val <- my.sapply(
+      X = 1:nrow(x = data.use),
+      FUN = function(x) {
+        return(wilcox.test(data.use[x, ] ~ group.info[, "group"], ...)$p.value)
+      }
+    )
+  }
   return(data.frame(p_val, row.names = rownames(x = data.use)))
 }
